@@ -15,26 +15,26 @@ SVDplot = function(object, order = 3, plot = TRUE, plot.type = c("fts", "image")
          plot(object, main = "Original data")
          for(i in 1:order){
              svdr[,,i] = as.matrix(pc[,i] * d[i]) %*% t(pcscore[,i])
-             plot(fts(as.numeric(rownames(data)), svdr[,,i]),ylab = "",xlab=xlab, main = paste(expression(SVD), i, sep=""))
+             plot(fts(object$x, svdr[,,i]),ylab = "",xlab=xlab, main = paste(expression(SVD), i, sep=""))
          }
          svdrecon = apply(svdr,c(1,2),sum)
          resi = data - svdrecon
-         plot(fts(as.numeric(rownames(data)), svdrecon), ylab ="",xlab=xlab, main = "Reconstruction")
-         plot(fts(as.numeric(rownames(data)), resi), ylab ="",xlab=xlab, main = "Residual")
+         plot(fts(object$x, svdrecon), ylab ="",xlab=xlab, main = "Reconstruction")
+         plot(fts(object$x, resi), ylab ="",xlab=xlab, main = "Residual")
       }
       else{
-         image(as.numeric(rownames(data)), as.numeric(colnames(data)), data, main = "Original data", xlab = xlab, ylab = object$yname) 
+         image(object$x, as.numeric(colnames(data)), data, main = "Original data", xlab = xlab, ylab = object$yname) 
          box()
          for(i in 1:order){
              svdr[,,i] = as.matrix(pc[,i] * d[i]) %*% t(pcscore[,i])
-             image(as.numeric(rownames(data)), as.numeric(colnames(data)), svdr[,,i],ylab = "",xlab=xlab, main = paste(expression(SVD), i, sep=""))
+             image(object$x, as.numeric(colnames(data)), svdr[,,i],ylab = "",xlab=xlab, main = paste(expression(SVD), i, sep=""))
              box()
          }
          svdrecon = apply(svdr,c(1,2),sum)
          resi = data - svdrecon
-         image(as.numeric(rownames(data)), as.numeric(colnames(data)), svdrecon, ylab = "", xlab = xlab, main = "Reconstruction")
+         image(object$x, as.numeric(colnames(data)), svdrecon, ylab = "", xlab = xlab, main = "Reconstruction")
          box()
-         image(as.numeric(rownames(data)), as.numeric(colnames(data)), resi, ylab = "", xlab = xlab, main = "Residual")        
+         image(object$x, as.numeric(colnames(data)), resi, ylab = "", xlab = xlab, main = "Residual")        
          box()
       }
   }
@@ -42,3 +42,5 @@ SVDplot = function(object, order = 3, plot = TRUE, plot.type = c("fts", "image")
       return(list(svds = svdr, reconstruction = svdrecon, residual = resi))
   }
 }
+
+
